@@ -1,8 +1,8 @@
-namedCapture.engine <- structure(function
+engine <- structure(function
 ### Get current regex engine used by str_match_named and
 ### str_match_all_named. RE2 is used by default if the re2r package is
 ### available; otherwise, PCRE is used by default. The user can set
-### \code{options(namedCapture.engine="PCRE")} to use PCRE even when
+### \code{options(engine="PCRE")} to use PCRE even when
 ### RE2 is available.
 (){
   RE2.available <- requireNamespace("re2r", quietly=TRUE)
@@ -17,9 +17,9 @@ namedCapture.engine <- structure(function
   }
 }, ex=function(){
 
-  namedCapture::namedCapture.engine()
-  old.opt <- options(namedCapture.engine="PCRE")
-  namedCapture::namedCapture.engine()
+  namedCapture::engine()
+  old.opt <- options(engine="PCRE")
+  namedCapture::engine()
   options(old.opt)
 
 })
